import { request } from '@/utils/request';

import type {
  addReportDto,
  addReportDetailDto,
  deleteReportDto,
  getReportListDto
} from '@/types/BiReport';

/**
 * 新增报表
 * @param addReportDto
 * @returns
 */
const addReport = (data: addReportDto) =>
  request<any>('/bi-manager/report/addReport', 'post', data);

/**
 * 新增报表详情
 * @param addReportDetailDto
 * @returns
 */
const addReportDetail = (data: addReportDetailDto) =>
  request<any>('/bi-manager/report/addReportDetail', 'post', data);

/**
 * 删除报表
 * @param deleteReportDto
 * @returns
 */
const deleteReport = (data: deleteReportDto) =>
  request<any>('/bi-manager/report/deleteReport', 'post', data);

/**
 * 删除报表详情
 * @param deleteReportDto
 * @returns
 */
const deleteReportDetail = (data: deleteReportDto) =>
  request<any>('/bi-manager/report/deleteReportDetail', 'post', data);

/**
 * 修改报表
 * @param addReportDto
 * @returns
 */
const editReport = (data: addReportDto & { id: string }) =>
  request<any>('/bi-manager/report/editReport', 'post', data);

/**
 * 修改报表详情
 * @param addReportDetailDto
 * @returns
 */
const editReportDetail = (data: addReportDetailDto & { id: string }) =>
  request<any>('/bi-manager/report/editReportDetail', 'post', data);

/**
 * 根据报表id查询详情
 * @param addReportDetailDto
 * @returns
 */
const getReportDetail = (data: { id: string }) =>
  request<any>('/bi-manager/report/getReportDetail', 'post', data);

/**
 * 查询报表列表
 * @param getReportListDto
 * @returns
 */
const getReportList = (data: getReportListDto) =>
  request<any>('/bi-manager/report/getReportList', 'post', data);

export default {
  addReport,
  addReportDetail,
  deleteReport,
  deleteReportDetail,
  editReport,
  editReportDetail,
  getReportDetail,
  getReportList
};
